@@ -15,12 +15,12 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-link-checker.cpp,v 1.10 2004/09/07 13:02:49 chpe Exp $
+ *  $Id: mozilla-link-checker.cpp,v 1.11 2004/12/08 15:33:52 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
+#include "mozilla-config.h"
+
 #include "config.h"
-#endif
 
 #include "mozilla-link-checker.h"
 
